% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/Integratemix.R
\name{Integratemix}
\alias{Integratemix}
\title{Integrated likelihood for mixtures using LPs and NLPs}
\usage{
Integratemix(mix, equalcol, y.s, MCMC, burn)
}
\arguments{
\item{mix}{is a set of initial values and parameters with the vector of values and hyperparameters.}

\item{equalcol}{TRUE if the same covariance matrix is considered for the mixture components.}

\item{y.s}{is a vector of values.}

\item{MCMC}{number of MCMC iterations.}

\item{burn}{number of iterationsto burn.}


}
\value{
Mu: the MAP for the component means.

local.integrate: the integrated likelihood under LPs.

non.local.integrate: the integrated likelihood under NLPs.
}
\description{
This function compute the Integrated Likelihood for Normal mixtures under LPs and NLPs
}
\examples{
#------------------------------------------------------
# MCMC: number of iterations for the MCMC
# burn: burning period
# Precision parameter g11 (for LPs) and g21 (for NLPs)
#-------------------------------------------------------
MCMC<-3
burn<-1
g11<-2.97
g21<-1.87
#-------------------------------------
# Missepecified Model
#-------------------------------------
set.seed(123456)
library(mvtnorm)
n.sample.miss<-600
sigma.s1<-matrix(c(1,-0.5,-0.5,1),2,2)
sigma.s2<-matrix(c(1,-0.5,-0.5,1),2,2)
sigma.s3<-matrix(c(1,-0.5,-0.5,1),2,2)
mu1.t<-c(-1,1)
mu2.t<-c(1,-1)
mu3.t<-c(6,6)
y.s<-rbind(rmvt(n.sample.miss/3,delta=mu1.t,sigma.s1, df = 4),
rmvt(n.sample.miss/3,delta=mu2.t,sigma.s2, df = 4),
rmvt(n.sample.miss/3,delta=mu3.t,sigma.s3, df = 4)
)
#------------------------------------------------------------
# Case: a common variance-covariance matrix for LPs for 
# the missespecified model with a 5 component mixture
#------------------------------------------------------------
#---------------
# Initial values
#---------------
library(mclust)
bic5 <- mclustBIC(y.s,G=5,modelNames = c("EEE")) 
mclust5 <- mclustModel(y.s,BICvalues=bic5) 
pars5 <- mclust5$parameters
#-----------------------------
# Integrated likelihood
#-----------------------------
mixMCMC5LP5=list(k=5,Mu0 = t(pars5$mean),
Sigma0 = pars5$variance$Sigma,
Ps0 = pars5$pro
, g=g11 , m=matrix(0,1,dim(y.s)[2]),
nu=5+(dim(y.s)[2]-1), S=diag(dim(y.s)[2])*((5+(dim(y.s)[2]-1))), alfa=1, penalize=1)
simu_LP5<-Integratemix(mixMCMC5LP5,equalcol=TRUE,y.s,MCMC,burn)
LP5<-simu_LP5$local.integrate
LP5
#------------------------------------------------------------
# Case: a common variance-covariance matrix for NLPs for 
# the missespecified model with a 3 component mixture
#------------------------------------------------------------ 
#---------------
# Initial values
#---------------
bic3 <- mclustBIC(y.s,G=3,modelNames = c("EEE")) 
mclust3 <- mclustModel(y.s,BICvalues=bic3) 
pars3 <- mclust3$parameters
#-----------------------------
# Integrated likelihood
#-----------------------------
mixMCMC3NLP3=list(k=3,Mu0 = t(pars3$mean),
Sigma0 = pars3$variance$Sigma,
Ps0 = pars3$pro
, g=g21 , m=matrix(0,1,dim(y.s)[2]),
nu=5+(dim(y.s)[2]-1), S=diag(dim(y.s)[2])*((5+(dim(y.s)[2]-1))), alfa=16.5, penalize=96)
simu_NLP3<-Integratemix(mixMCMC3NLP3,equalcol=TRUE,y.s,MCMC,burn)
NLP3<-simu_NLP3$non.local.integrate
NLP3
}

