% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/emLP.R
\name{emLP}
\alias{emLP}
\title{EM algorithm for mixtures using LPs}
\usage{
emLP(mix, y.s, tol, equalcol)
}
\arguments{
\item{mix}{is a set of initial values and hyperparameters.}

\item{y.s}{is a vector of values.}

\item{tol}{is the tolerance for the EM algorithm.}

\item{equalcol}{TRUE if the same covariance matrix is considered for the mixture components.}
}
\value{
Mu: the MAP for the component means.

Sigma: the MAP for the component covariance matrix.

P: the MAP for the component weights.

z: the MAP for the latent variables of the missing data structure.
}
\description{
This function compute the EM algorithm for Normal mixtures under LPs
}
\examples{
#-------------------------------------
# Missepecified Model
#-------------------------------------
set.seed(123456)
library(mvtnorm)
n.sample.miss<-600
sigma.s1<-matrix(c(1,-0.5,-0.5,1),2,2)
sigma.s2<-matrix(c(1,-0.5,-0.5,1),2,2)
sigma.s3<-matrix(c(1,-0.5,-0.5,1),2,2)
mu1.t<-c(-1,1)
mu2.t<-c(1,-1)
mu3.t<-c(6,6)
y.s<-rbind(rmvt(n.sample.miss/3,delta=mu1.t,sigma.s1, df = 4),
rmvt(n.sample.miss/3,delta=mu2.t,sigma.s2, df = 4),
rmvt(n.sample.miss/3,delta=mu3.t,sigma.s3, df = 4)
)
y.s2<-as.data.frame(y.s)
plot(y.s2)
#--------------------------
# Number of components
#--------------------------
number.c.LPs.cov<-5
#----------------------------------------------
# Initial values
#----------------------------------------------
library(mclust)
bic.cov <- mclustBIC(y.s2,G=number.c.LPs.cov,modelNames = c("EEE")) 
mclust.cov <- mclustModel(y.s,BICvalues=bic.cov ) 
pars.cov <- mclust.cov$parameters
mixEMLPs.cov=list(k=number.c.LPs.cov,Mu0 = t(pars.cov$mean),
Sigma = pars.cov$variance$Sigma,
Ps = pars.cov$pro
, g=2.97, m=matrix(0,1,dim(y.s)[2]),
nu=5+(dim(y.s)[2]-1), S=diag(dim(y.s)[2])*((5+(dim(y.s)[2]-1))), alfa=1)
#----------------------------------------------
# Running the function
#----------------------------------------------
EM.results.cov<-emLP(mixEMLPs.cov,y.s,0.001, equalcol=TRUE)
#--------------------------------------------------------------
# Plot using the EM package
#--------------------------------------------------------------
parametersBIC.cov<-mclust.cov$parameters
parametersBIC.cov$pro<-EM.results.cov$P
parametersBIC.cov$mean<-t(EM.results.cov$Mu)
parametersBIC.cov$variance$Sigma<-EM.results.cov$Sigma
parametersBIC.cov$variance$sigma[,,1]<-EM.results.cov$Sigma
parametersBIC.cov$variance$sigma[,,2]<-EM.results.cov$Sigma
parametersBIC.cov$variance$sigma[,,3]<-EM.results.cov$Sigma
parametersBIC.cov$variance$sigma[,,4]<-EM.results.cov$Sigma
parametersBIC.cov$variance$sigma[,,5]<-EM.results.cov$Sigma
parametersBIC.cov$variance$cholSigma<-chol(EM.results.cov$Sigma)
parametersBIC.cov$z<-EM.results.cov$z
parametersBIC2miss.cov<-parametersBIC.cov
mclust2Dplot(data = y.s2, what = "classification",
parameters = parametersBIC2miss.cov, z = parametersBIC2miss.cov$z,CEX=0.65,col=8)
}

